@@ -108,6 +108,11 @@ go_plugin_loader_module_load_base (GOPluginLoader *loader, GOErrorInfo **err)
 	full_module_file_name = g_build_filename (go_plugin_get_dir_name (
 		go_plugin_loader_get_plugin (loader)),
 		loader_module->module_file_name, NULL);
+
+	if (go_debug_flag ("plugin"))
+		g_printerr ("Loading module file %s\n",
+			    full_module_file_name);
+
 	handle = g_module_open (full_module_file_name, G_MODULE_BIND_LAZY);
 	if (handle == NULL) {
 		*err = go_error_info_new_printf (
@@ -133,8 +138,11 @@ go_plugin_loader_module_load_base (GOPluginLoader *loader, GOErrorInfo **err)
 				(loader_module->plugin_init) (go_plugin_loader_get_plugin (loader), NULL);
 		}
 
-		if (*err != NULL)
+		if (*err != NULL) {
+			if (go_debug_flag ("plugin"))
+				g_printerr ("Error while loading module\n");
 			g_module_close (handle);
+		}
 	}
 	g_free (full_module_file_name);
 }
@@ -148,6 +156,16 @@ go_plugin_loader_module_unload_base (GOPluginLoader *loader, GOErrorInfo **ret_e
 	if (loader_module->plugin_shutdown != NULL) {
 		loader_module->plugin_shutdown (go_plugin_loader_get_plugin (loader), NULL);
 	}
+	if (go_debug_flag ("plugin")) {
+		char *full_module_file_name =
+			g_build_filename
+			(go_plugin_get_dir_name (go_plugin_loader_get_plugin (loader)),
+			 loader_module->module_file_name,
+			 NULL);
+
+		g_printerr ("Unloading %s\n", full_module_file_name);
+		g_free (full_module_file_name);
+	}
 	if (!g_module_close (loader_module->handle)) {
 		*ret_error = go_error_info_new_printf (
 			_("Unable to close module file \"%s\"."),
