@@ -33,12 +33,15 @@
  * #GocPath implements path drawing in the canvas.
 **/
 
+static GObjectClass *parent_class;
+
 enum {
 	PATH_PROP_0,
 	PATH_PROP_X,
 	PATH_PROP_Y,
 	PATH_PROP_ROTATION,
 	PATH_PROP_CLOSED,
+	PATH_PROP_FILL_RULE,
 	PATH_PROP_PATH,
 };
 
@@ -65,8 +68,14 @@ goc_path_set_property (GObject *gobject, guint param_id,
 		path->closed = g_value_get_boolean (value);
 		break;
 
+	case PATH_PROP_FILL_RULE:
+		path->fill_rule = g_value_get_boolean (value);
+		break;
+
 	case PATH_PROP_PATH:
-		path->path = g_value_peek_pointer (value);
+		if (path->path)
+			go_path_free (path->path);
+		path->path = go_path_ref (g_value_get_boxed (value));
 		break;
 
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, param_id, pspec);
@@ -98,6 +107,10 @@ goc_path_get_property (GObject *gobject, guint param_id,
 		g_value_set_boolean (value, path->closed);
 		break;
 
+	case PATH_PROP_FILL_RULE:
+		g_value_set_boolean (value, path->fill_rule);
+		break;
+
 	case PATH_PROP_PATH:
 		g_value_set_boxed (value, &path->path);
 		break;
@@ -115,6 +128,7 @@ goc_path_prepare_draw (GocItem const *item, cairo_t *cr, gboolean flag)
 	double rsign = sign;
 
 	cairo_save (cr);
+	cairo_set_fill_rule (cr, path->fill_rule);
 	if (1 == flag) {
 		goc_group_cairo_transform (item->parent, cr, path->x , path->y);
 		sign = 1;
@@ -224,14 +238,25 @@ goc_path_init_style (G_GNUC_UNUSED GocStyledItem *item, GOStyle *style)
 	}
 }
 
+static void
+goc_path_finalize (GObject *obj)
+{
+	GocPath *path = GOC_PATH (obj);
+	if (path->path)
+		go_path_free (path->path);
+	parent_class->finalize (obj);
+}
+
 static void
 goc_path_class_init (GocItemClass *item_klass)
 {
 	GObjectClass *obj_klass = (GObjectClass *) item_klass;
 	GocStyledItemClass *gsi_klass = (GocStyledItemClass *) item_klass;
+	parent_class = g_type_class_peek_parent (item_klass);
 
 	gsi_klass->init_style = goc_path_init_style;
 
+	obj_klass->finalize = goc_path_finalize;
 	obj_klass->get_property = goc_path_get_property;
 	obj_klass->set_property = goc_path_set_property;
 	g_object_class_install_property (obj_klass, PATH_PROP_X,
@@ -258,6 +283,12 @@ goc_path_class_init (GocItemClass *item_klass)
 			_("The flag for closed path"),
 			FALSE,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
+	g_object_class_install_property (obj_klass, PATH_PROP_FILL_RULE,
+		g_param_spec_boolean ("fill-rule",
+				      _("Fill rule"),
+				      _("Set fill rule to winding or even/odd"),
+				      FALSE,
+				      GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	g_object_class_install_property (obj_klass, PATH_PROP_PATH,
 		g_param_spec_boxed ("path",
 			_("Path"),
