@@ -435,24 +435,6 @@ cb_position_toggled (GtkWidget *button, AxisBasePrefs *state)
 		gtk_widget_set_sensitive (go_gtk_builder_get_widget (state->gui, "padding-spinbutton"),
 					  position != GOG_AXIS_CROSS);
 
-	if (position != GOG_AXIS_CROSS) {
-		axes = gog_chart_get_axes (axis_base->chart, gog_axis_get_atype (axis_base->axis));
-		for (aptr = axes; aptr != NULL; aptr = aptr->next) {
-			lines = gog_object_get_children (GOG_OBJECT (aptr->data), NULL);
-			lines = g_slist_prepend (lines, aptr->data);
-			for (lptr = lines; lptr != NULL; lptr = lptr->next) {
-				if (lptr->data == axis_base || !GOG_IS_AXIS_BASE (lptr->data))
-					continue;
-				if (position == gog_axis_base_get_position (GOG_AXIS_BASE (lptr->data))) {
-					gog_axis_base_set_position (GOG_AXIS_BASE (lptr->data),
-								    gog_axis_base_get_position (axis_base));
-					break;
-				}
-			}
-			g_slist_free (lines);
-		}
-		g_slist_free (axes);
-	}
 	gog_axis_base_set_position (axis_base, position);
 	gog_object_emit_changed (GOG_OBJECT (axis_base), TRUE);
 }
@@ -507,7 +489,7 @@ gog_axis_base_populate_editor (GogObject *gobj,
 		return;
 	}
 
-	gui = go_gtk_builder_new_internal ("gog-axis-prefs.ui", GETTEXT_PACKAGE, cc);
+	gui = go_gtk_builder_new_internal ("res:go:graph/gog-axis-prefs.ui", GETTEXT_PACKAGE, cc);
 	if (gui == NULL) {
 		(GOG_OBJECT_CLASS(gab_parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
 		return;
@@ -1010,7 +992,7 @@ axis_line_get_bbox (GogAxisBase *axis_base, GogRenderer *renderer,
 	major_tick_len = gog_renderer_pt2r (renderer, axis_base->major.size_pts);
 	tick_len = axis_base->major.tick_out ? major_tick_len :
 		(axis_base->minor.tick_out ? minor_tick_len : 0.);
-	gog_renderer_get_text_OBR (renderer, "0", TRUE, &txt_obr);
+	gog_renderer_get_text_OBR (renderer, "0", TRUE, &txt_obr, -1.);
 	label_padding = txt_obr.w;
 
 	total_bbox.x = x; total_bbox.y = y;
@@ -1056,7 +1038,7 @@ axis_line_get_bbox (GogAxisBase *axis_base, GogRenderer *renderer,
 	for (i = 0; i < tick_nbr; i++) {
 		if (ticks[i].str != NULL) {
 			GOGeometryOBR *obr = obrs + i;
-			gog_renderer_get_gostring_OBR (renderer, ticks[i].str, obr);
+			gog_renderer_get_gostring_OBR (renderer, ticks[i].str, obr, -1.);
 			if (obr->w > label_size_max
 			    || obr->h > label_size_max) {
 				label_size_max = MAX (obr->w, obr->h);
@@ -1131,12 +1113,14 @@ axis_line_render (GogAxisBase *axis_base,
 	is_line_visible = go_style_is_line_visible (style);
 	line_width = gog_renderer_line_size (renderer, style->line.width) / 2;
 
-	if (is_line_visible)
-	{
+	if (is_line_visible) {
+		/* draw the line only in the effective range */
+		double s, e;
+		gog_axis_get_effective_span (axis_base->axis, &s, &e);
 		path = go_path_new ();
 		go_path_set_options (path, sharp ? GO_PATH_OPTIONS_SHARP : 0);
-		go_path_move_to (path, x, y);
-		go_path_line_to (path, x + w, y + h);
+		go_path_move_to (path, x + w * s , y + h * s);
+		go_path_line_to (path, x + w * e, y + h * e);
 	}
 
 	map = gog_axis_map_new (axis_base->axis, 0., axis_length);
@@ -1158,7 +1142,7 @@ axis_line_render (GogAxisBase *axis_base,
 
 	tick_len = axis_base->major.tick_out ? major_tick_len :
 		(axis_base->minor.tick_out ? minor_tick_len : 0.);
-	gog_renderer_get_text_OBR (renderer, "0", TRUE, &zero_obr);
+	gog_renderer_get_text_OBR (renderer, "0", TRUE, &zero_obr, -1.);
 	label_padding = zero_obr.w;
 
 	tick_nbr = gog_axis_get_ticks (axis_base->axis, &ticks);
@@ -1168,7 +1152,7 @@ axis_line_render (GogAxisBase *axis_base,
 		for (i = 0; i < tick_nbr; i++) {
 			if (ticks[i].str != NULL) {
 				GOGeometryOBR *obr = obrs + i;
-				gog_renderer_get_gostring_OBR (renderer, ticks[i].str, obr);
+				gog_renderer_get_gostring_OBR (renderer, ticks[i].str, obr, -1.);
 				if (obr->w > label_size_max
 				    || obr->h > label_size_max) {
 					label_size_max = MAX (obr->w, obr->h);
@@ -1268,7 +1252,8 @@ axis_line_render (GogAxisBase *axis_base,
 			label_pos.x = obrs[j].x;
 			label_pos.y = obrs[j].y;
 			gog_renderer_draw_gostring (renderer, ticks[j].str,
-						    &label_pos, GO_ANCHOR_CENTER);
+						    &label_pos, GO_ANCHOR_CENTER,
+			                            GTK_JUSTIFY_CENTER, -1.);
 		}
 	}
 	g_free (obrs);
@@ -1323,7 +1308,7 @@ axis_circle_get_bbox (GogAxisBase *axis_base, GogRenderer *renderer,
 	major_tick_len = gog_renderer_pt2r (renderer, axis_base->major.size_pts);
 	tick_len = axis_base->major.tick_out ? major_tick_len :
 		(axis_base->minor.tick_out ? minor_tick_len : 0.);
-	gog_renderer_get_text_OBR (renderer, "0", TRUE, &txt_obr);
+	gog_renderer_get_text_OBR (renderer, "0", TRUE, &txt_obr, -1.);
 	label_padding = txt_obr.w;
 
 	draw_ticks = go_style_is_line_visible (axis_base->base.style) &&
@@ -1338,7 +1323,7 @@ axis_circle_get_bbox (GogAxisBase *axis_base, GogRenderer *renderer,
 		gog_chart_map_2D_to_view (c_map, ticks[i].position, position, &x, &y);
 
 		if (ticks[i].str != NULL && draw_labels) {
-			gog_renderer_get_gostring_OBR (renderer, ticks[i].str, &txt_obr);
+			gog_renderer_get_gostring_OBR (renderer, ticks[i].str, &txt_obr, -1.);
 			txt_obr.w += label_padding;
 			go_geometry_calc_label_position (&txt_obr, angle + M_PI / 2.0, tick_len,
 							 GO_SIDE_LEFT, GO_SIDE_AUTO);
@@ -1406,7 +1391,7 @@ axis_circle_render (GogAxisBase *axis_base, GogRenderer *renderer,
 	major_tick_len = gog_renderer_pt2r (renderer, axis_base->major.size_pts);
 	tick_len = axis_base->major.tick_out ? major_tick_len :
 		(axis_base->minor.tick_out ? minor_tick_len : 0.);
-	gog_renderer_get_text_OBR (renderer, "0", TRUE, &txt_obr);
+	gog_renderer_get_text_OBR (renderer, "0", TRUE, &txt_obr, -1.);
 	label_padding = txt_obr.w;
 
 	tick_nbr = gog_axis_get_ticks (axis_base->axis, &ticks);
@@ -1462,7 +1447,7 @@ axis_circle_render (GogAxisBase *axis_base, GogRenderer *renderer,
 		if (ticks[i].str != NULL && draw_labels) {
 			gog_chart_map_2D_to_view (c_map, ticks[i].position, position,
 						  &label_pos.x, &label_pos.y);
-			gog_renderer_get_gostring_OBR (renderer, ticks[i].str, &txt_obr);
+			gog_renderer_get_gostring_OBR (renderer, ticks[i].str, &txt_obr, -1.);
 			txt_obr.w += label_padding;
 			go_geometry_calc_label_position (&txt_obr, angle + M_PI / 2.0, tick_len,
 							 GO_SIDE_LEFT, GO_SIDE_AUTO);
@@ -1475,7 +1460,8 @@ axis_circle_render (GogAxisBase *axis_base, GogRenderer *renderer,
 			     !go_geometry_test_OBR_overlap (&txt_obr, &txt_obr_first))) {
 				gog_renderer_draw_gostring
 					(renderer, ticks[i].str,
-					 &label_pos, GO_ANCHOR_CENTER);
+					 &label_pos, GO_ANCHOR_CENTER,
+					 GTK_JUSTIFY_CENTER, -1.);
 				txt_obr_old = txt_obr;
 			}
 			if (!first_label_done) {
@@ -2056,7 +2042,7 @@ xyz_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 			tick_nbr = gog_axis_get_ticks (axis_base->axis, &ticks);
 
 			gog_renderer_get_text_OBR (view->renderer,
-				"0", TRUE, &obr);
+				"0", TRUE, &obr, -1.);
 			tick_len += fabs (obr.w * ox);
 			if (axis_base->major_tick_labeled) {
 				label_w = label_h = 0;
@@ -2066,7 +2052,7 @@ xyz_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 					gog_renderer_get_text_OBR
 						(view->renderer,
 						 ticks[i].str->str,
-						 FALSE, &obr);
+						 FALSE, &obr, -1.);
 					if (obr.w > label_w)
 						label_w = obr.w;
 					if (obr.h > label_h)
