@@ -1724,17 +1724,31 @@ gog_axis_map_get_baseline (GogAxisMap *map)
 void
 gog_axis_map_get_extents (GogAxisMap *map, double *start, double *stop)
 {
+	double x0, x1;
 	g_return_if_fail (map != NULL);
 
-	if (map->axis->inverted)
-		map->desc->map_bounds (map, stop, start);
+	if (gog_axis_is_inverted (map->axis))
+		map->desc->map_bounds (map, &x1, &x0);
 	else
-		map->desc->map_bounds (map, start, stop);
+		map->desc->map_bounds (map, &x0, &x1);
 	if (map->axis->type != GOG_AXIS_CIRCULAR) {
-		double buf = (*stop - *start) / (map->axis->span_end - map->axis->span_start);
-		*start -= map->axis->span_start * buf;
-		*stop = *start + buf;
+		if (gog_axis_is_discrete (map->axis)) {
+			double buf = (x1 - x0) / (map->axis->span_end - map->axis->span_start);
+			x0 -= map->axis->span_start * buf;
+			x1 = x0 + buf;
+		} else {
+			double t, buf;
+			t = gog_axis_map_to_view (map, x0);
+			buf = (gog_axis_map_to_view (map, x1) - t) / (map->axis->span_end - map->axis->span_start);
+			t -= map->axis->span_start * buf;
+			x0 = gog_axis_map_from_view (map, t);
+			x1 = gog_axis_map_from_view (map, t + buf);
+		}
 	}
+	if (start)
+		*start = x0;
+	if (stop)
+		*stop = x1;
 }
 
 /**
@@ -1752,14 +1766,31 @@ gog_axis_map_get_extents (GogAxisMap *map, double *start, double *stop)
 void
 gog_axis_map_get_bounds (GogAxisMap *map, double *minimum, double *maximum)
 {
+	double x0, x1;
 	g_return_if_fail (map != NULL);
 
-	map->desc->map_bounds (map, minimum, maximum);
+	if (gog_axis_is_inverted (map->axis))
+		map->desc->map_bounds (map, &x1, &x0);
+	else
+		map->desc->map_bounds (map, &x0, &x1);
 	if (map->axis->type != GOG_AXIS_CIRCULAR) {
-		double buf = (*minimum - *maximum) / (map->axis->span_end - map->axis->span_start);
-		*maximum -= map->axis->span_start * buf;
-		*minimum = *maximum + buf;
+		if (gog_axis_is_discrete (map->axis)) {
+			double buf = (x1 - x0) / (map->axis->span_end - map->axis->span_start);
+			x0 -= map->axis->span_start * buf;
+			x1 = x0 + buf;
+		} else {
+			double t, buf;
+			t = gog_axis_map_to_view (map, x0);
+			buf = (gog_axis_map_to_view (map, x1) - t) / (map->axis->span_end - map->axis->span_start);
+			t -= map->axis->span_start * buf;
+			x0 = gog_axis_map_from_view (map, t);
+			x1 = gog_axis_map_from_view (map, t + buf);
+		}
 	}
+	if (minimum)
+		*minimum = (map->axis->inverted)? x1: x0;
+	if (maximum)
+		*maximum = (map->axis->inverted)? x0: x1;
 }
 
 /**
@@ -2531,7 +2562,7 @@ gog_axis_populate_editor (GogObject *gobj,
 	GogDataset *set = GOG_DATASET (gobj);
 	GtkBuilder *gui;
 
-	gui = go_gtk_builder_new_internal ("gog-axis-prefs.ui", GETTEXT_PACKAGE, cc);
+	gui = go_gtk_builder_new_internal ("res:go:graph/gog-axis-prefs.ui", GETTEXT_PACKAGE, cc);
 	if (gui == NULL)
 		return;
 
@@ -3402,8 +3433,8 @@ gog_axis_view_size_allocate (GogView *view, GogViewAllocation const *bbox)
 						}
 						tmp.h -= req.h + pad_h;
 					} else {
-						child_bbox.y = plot_area->y +
-							(plot_area->h * (start + end) - req.h) / 2.0;
+						child_bbox.y = plot_area->y + plot_area->h -
+							(plot_area->h * (start + end) + req.h) / 2.0;
 						child_bbox.h = req.h;
 						child_bbox.w = req.w;
 						switch (axis_pos) {
