@@ -112,6 +112,9 @@ typedef enum {
 	F_FRACTION_MIN_DENOM_DIGITS,
 	F_FRACTION_PI_SCALE,
 	F_BASE_SEPARATOR,
+	F_DECIMAL_GRID,
+	F_FRACTION_GRID,
+	F_FRACTION_GRID1,
 	F_MAX_WIDGET
 } FormatWidget;
 
@@ -129,7 +132,7 @@ struct  _GOFormatSel {
 
 	struct {
 		GtkTextView	*preview;
-		GtkWidget	*preview_box;
+		GtkWidget	*preview_grid;
 		GtkTextBuffer	*preview_buffer;
 
 		GtkWidget	*widget[F_MAX_WIDGET];
@@ -298,7 +301,7 @@ fillin_negative_samples (GOFormatSel *gfs)
 
 static struct {
 	char const *name;
-	char const * unit;
+	char const *unit;
 	int scale;
 } si_units[] = {
 	{N_("A (ampere)"), "A", 0},
@@ -333,7 +336,7 @@ static struct {
 };
 
 static void
-load_si_combo (GtkWidget *w, GOFormatSel *gfs)
+load_si_combo (GtkWidget *w, G_GNUC_UNUSED GOFormatSel *gfs)
 {
 	GtkComboBox *c = GTK_COMBO_BOX (w);
 	GtkListStore *store = GTK_LIST_STORE (gtk_combo_box_get_model (c));
@@ -481,15 +484,26 @@ cb_si_unit_toggle (GtkWidget *w, GOFormatSel *gfs)
 			}
 		} else
 			gfs->format.details.appended_SI_unit = NULL;
-	} else
+	} else {
+		guint i;
 		gfs->format.details.appended_SI_unit = g_strdup (gfs->format.default_si_unit);
+		gfs->format.details.scale = 1;
+		if (gfs->format.details.appended_SI_unit != NULL)
+			for (i=0; i < G_N_ELEMENTS (si_units); i++)
+				if (0 == strcmp (si_units[i].unit, gfs->format.details.appended_SI_unit)) {
+					gfs->format.details.scale = si_units[i].scale;
+					break;
+				}
+	}
 
 	draw_format_preview (gfs, TRUE);
 }
 
 static void
-cb_si_combo_changed (GtkWidget *w, GOFormatSel *gfs)
+cb_si_combo_changed (G_GNUC_UNUSED GtkWidget *w, GOFormatSel *gfs)
 {
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gfs->format.widget[F_SI_SI_UNIT_BUTTON]),
+				      TRUE);
 	cb_si_unit_toggle (gfs->format.widget[F_SI_SI_UNIT_BUTTON], gfs);
 }
 
@@ -649,7 +663,7 @@ static void
 fmt_dialog_enable_widgets (GOFormatSel *gfs, int page)
 {
 	SETUP_LOCALE_SWITCH;
-	static FormatWidget const contents[][17] = {
+	static FormatWidget const contents[][20] = {
 		/* General */
 		{
 			F_GENERAL_EXPLANATION,
@@ -658,6 +672,7 @@ fmt_dialog_enable_widgets (GOFormatSel *gfs, int page)
 		/* Number */
 		{
 			F_NUMBER_EXPLANATION,
+			F_DECIMAL_GRID,
 			F_DECIMAL_LABEL,
 			F_DECIMAL_SPIN,
 			F_SEPARATOR,
@@ -669,6 +684,7 @@ fmt_dialog_enable_widgets (GOFormatSel *gfs, int page)
 		/* Currency */
 		{
 			F_CURRENCY_EXPLANATION,
+			F_DECIMAL_GRID,
 			F_DECIMAL_LABEL,
 			F_DECIMAL_SPIN,
 			F_SEPARATOR,
@@ -682,6 +698,7 @@ fmt_dialog_enable_widgets (GOFormatSel *gfs, int page)
 		/* Accounting */
 		{
 			F_ACCOUNTING_EXPLANATION,
+			F_DECIMAL_GRID,
 			F_DECIMAL_LABEL,
 			F_DECIMAL_SPIN,
 			F_SYMBOL_LABEL,
@@ -707,6 +724,7 @@ fmt_dialog_enable_widgets (GOFormatSel *gfs, int page)
 		/* Percentage */
 		{
 			F_PERCENTAGE_EXPLANATION,
+			F_DECIMAL_GRID,
 			F_DECIMAL_LABEL,
 			F_DECIMAL_SPIN,
 			F_SEPARATOR,
@@ -717,6 +735,9 @@ fmt_dialog_enable_widgets (GOFormatSel *gfs, int page)
 		},
 		/* Fraction */
 		{
+			F_FRACTION_GRID,
+			F_FRACTION_GRID1,
+			F_DECIMAL_GRID,
 			F_FRACTION_EXPLANATION,
 			F_FRACTION_SEPARATE_INTEGER,
 			F_FRACTION_MIN_INTEGER_DIGITS_LABEL,
@@ -740,6 +761,7 @@ fmt_dialog_enable_widgets (GOFormatSel *gfs, int page)
 		/* Scientific */
 		{
 			F_SCIENTIFIC_EXPLANATION,
+			F_DECIMAL_GRID,
 			F_DECIMAL_LABEL,
 			F_DECIMAL_SPIN,
 			F_ENGINEERING_BUTTON,
@@ -943,17 +965,19 @@ stays:
 
 		case F_SI_CUSTOM_UNIT_BUTTON:
 #ifdef ALLOW_SI_APPEND
+			gtk_widget_set_sensitive (w, gfs->format.details.append_SI);
 			/* This is set through F_SI_UNIT_COMBO */
 #else
-				show_widget = FALSE;
+			show_widget = FALSE;
 #endif
 			break;
 
 		case F_SI_SI_UNIT_BUTTON:
 #ifdef ALLOW_SI_APPEND
+			gtk_widget_set_sensitive (w, gfs->format.details.append_SI);
 			/* This is set through F_SI_UNIT_COMBO */
 #else
-				show_widget = FALSE;
+			show_widget = FALSE;
 #endif
 			break;
 
@@ -962,6 +986,7 @@ stays:
 			gint row = -1;
 			guint ii;
 
+			gtk_widget_set_sensitive (w, gfs->format.details.append_SI);
 			if (gfs->format.details.appended_SI_unit != NULL) {
 				char const *unit = gfs->format.details.appended_SI_unit;
 				if (unit[0] == 'g' && unit[1] == 0)
@@ -1415,6 +1440,9 @@ nfs_init (GOFormatSel *gfs)
 		"format_pi_scale_check",
 
 		"format_base_separator",
+		"format-decimal-grid",
+		"fraction-grid",
+		"fraction-grid1",
 		NULL
 	};
 
@@ -1431,11 +1459,11 @@ nfs_init (GOFormatSel *gfs)
 	gfs->show_format_with_markup = FALSE;
 	gfs->locale = NULL;
 
-	gfs->gui = go_gtk_builder_new_internal ("go-format-sel.ui", GETTEXT_PACKAGE, NULL);
+	gfs->gui = go_gtk_builder_new_internal ("res:go:gtk/go-format-sel.ui", GETTEXT_PACKAGE, NULL);
 	if (gfs->gui == NULL)
 		return;
 
-	toplevel = go_gtk_builder_get_widget (gfs->gui, "number_box");
+	toplevel = go_gtk_builder_get_widget (gfs->gui, "number-grid");
 	gtk_box_pack_start (GTK_BOX (gfs), toplevel, TRUE, TRUE, 0);
 
 	gfs->format.spec = go_format_general ();
@@ -1450,7 +1478,7 @@ nfs_init (GOFormatSel *gfs)
 
 	study_format (gfs->format.spec, &gfs->format.details);
 
-	gfs->format.preview_box = go_gtk_builder_get_widget (gfs->gui, "preview_box");
+	gfs->format.preview_grid = go_gtk_builder_get_widget (gfs->gui, "preview-grid");
 	gfs->format.preview = GTK_TEXT_VIEW (gtk_builder_get_object (gfs->gui, "preview"));
 	{
 		PangoFontMetrics *metrics;
@@ -1504,7 +1532,7 @@ nfs_init (GOFormatSel *gfs)
 				   gfs->format.widget[F_DECIMAL_LABEL]);
 
 	/* hide preview by default until a value is set */
-	gtk_widget_hide (gfs->format.preview_box);
+	gtk_widget_hide (gfs->format.preview_grid);
 
 	/* setup the structure of the negative type list */
 	gfs->format.negative_types.model =
@@ -1616,8 +1644,8 @@ nfs_init (GOFormatSel *gfs)
 			GTK_LABEL (gtk_builder_get_object (gfs->gui, "format_symbol_label")),
 			GTK_WIDGET (combo));
 		/* add the combo to its container */
-		gtk_box_pack_start (GTK_BOX (gtk_builder_get_object (gfs->gui, "format_symbol_box")),
-				    GTK_WIDGET (combo), TRUE, TRUE, 0);
+		gtk_container_add (GTK_CONTAINER (gtk_builder_get_object (gfs->gui, "format-symbol-grid")),
+				    GTK_WIDGET (combo));
 	}
 
 	/* Setup special handler for Custom */
@@ -1666,10 +1694,10 @@ go_format_sel_finalize (GObject *obj)
 }
 
 static gboolean
-accumulate_first_string (GSignalInvocationHint *ihint,
-			 GValue                *accum_result,
-			 const GValue          *handler_result,
-			 gpointer               data)
+accumulate_first_string (G_GNUC_UNUSED GSignalInvocationHint *ihint,
+			 GValue                              *accum_result,
+			 const GValue                        *handler_result,
+			 G_GNUC_UNUSED gpointer               data)
 {
 	gchar const *str = g_value_get_string (handler_result);
 	if (NULL != str) {
@@ -1818,7 +1846,7 @@ void
 go_format_sel_show_preview (GOFormatSel *gfs)
 {
 	g_return_if_fail (GO_IS_FORMAT_SEL (gfs));
-	gtk_widget_show (gfs->format.preview_box);
+	gtk_widget_show (gfs->format.preview_grid);
 	draw_format_preview (gfs, TRUE);
 }
 
@@ -1826,7 +1854,7 @@ void
 go_format_sel_hide_preview (GOFormatSel *gfs)
 {
 	g_return_if_fail (GO_IS_FORMAT_SEL (gfs));
-	gtk_widget_hide (gfs->format.preview_box);
+	gtk_widget_hide (gfs->format.preview_grid);
 }
 
 void
