@@ -136,14 +136,18 @@ void go_render_general  (PangoLayout *layout, GString *str,
 			 const GOFontMetrics *metrics,
 			 double val,
 			 int col_width,
-			 gboolean unicode_minus);
+			 gboolean unicode_minus,
+			 guint numeral_shape,
+			 guint custom_shape_flags);
 #ifdef GOFFICE_WITH_LONG_DOUBLE
 void go_render_generall (PangoLayout *layout, GString *str,
 			 GOFormatMeasure measure,
 			 const GOFontMetrics *metrics,
 			 long double val,
 			 int col_width,
-			 gboolean unicode_minus);
+			 gboolean unicode_minus,
+			 guint numeral_shape,
+			 guint custom_shape_flags);
 #endif
 
 /*************************************************************************/
