@@ -305,6 +305,34 @@ go_string_replace (GString *target,
 		g_string_insert_len (target, pos, txt, newlen);
 }
 
+int
+go_unichar_issign (gunichar uc)
+{
+	switch (uc) {
+	case '+':
+	case 0x207a: /* Superscript plus */
+	case 0x208a: /* Subscript plus */
+	case 0x2795: /* Unicode heavy plus */
+	case 0xfb29: /* Hebrew plus */
+	case 0xfe62: /* Unicode small plus */
+	case 0xff0b: /* Variant of '+' for CJK */
+		return +1;
+	case '-':
+	/* case 0x2052: /\* Commercial minus *\/ */
+	case 0x207b: /* Superscript minus */
+	case 0x208b: /* Subscript minus */
+	case 0x2212: /* Unicode minus */
+	case 0x2796: /* Unicode heavy minus */
+	case 0x8ca0: /* Traditional Chinese minus */
+	case 0x8d1f: /* Simplified Chinese minus */
+	case 0xfe63: /* Unicode small minus */
+	case 0xff0d: /* Variant of '-' for CJK */
+		return -1;
+	default:
+		return 0;
+	}
+}
+
 /* ------------------------------------------------------------------------- */
 
 /**
@@ -637,7 +665,7 @@ go_guess_encoding (const char *raw, size_t len, const char *user_guess,
 		   GString **utf8_str, guint *truncated)
 {
 	int try;
-	gboolean debug = FALSE;
+	gboolean debug = go_debug_flag ("encoding");
 
 	g_return_val_if_fail (raw != NULL, NULL);
 
@@ -681,7 +709,7 @@ go_guess_encoding (const char *raw, size_t len, const char *user_guess,
 			continue;
 
 		if (debug)
-			g_print ("Trying %s as encoding.\n", guess);
+			g_printerr ("Trying %s as encoding.\n", guess);
 
 		utf8_data = g_convert (raw, len, "UTF-8", guess,
 				       &bytes_read, &bytes_written, &error);
@@ -695,7 +723,7 @@ go_guess_encoding (const char *raw, size_t len, const char *user_guess,
 				continue;
 			}
 			if (debug)
-				g_print ("Guessed %s as encoding.\n", guess);
+				g_printerr ("Guessed %s as encoding.\n", guess);
 			if (utf8_str)
 				*utf8_str = g_string_new_len
 					(utf8_data, bytes_written);
@@ -1029,6 +1057,16 @@ syntax:
 	goto done;
 }
 
+gboolean
+go_debug_flag (const char *flag)
+{
+	GDebugKey key;
+	key.key = (char *)flag;
+	key.value = 1;
+
+	return g_parse_debug_string (g_getenv ("GO_DEBUG"), &key, 1) != 0;
+}
+
 void
 _go_glib_extras_shutdown (void)
 {
