@@ -42,6 +42,8 @@
 #include <glib/gi18n-lib.h>
 #include <gsf/gsf-impl-utils.h>
 
+#include "embedded-stuff.c"
+
 GOFFICE_PLUGIN_MODULE_HEADER;
 
 enum {
@@ -394,7 +396,7 @@ GSF_DYNAMIC_CLASS_ABSTRACT (GogPlot1_5d, gog_plot1_5d,
 	GOG_TYPE_PLOT)
 
 double _gog_plot1_5d_get_percent_value (GogPlot *plot, unsigned series, unsigned index)
-{ 
+{
 	GogPlot1_5d *model = GOG_PLOT1_5D (plot);
 	GogSeries1_5d const *ser = NULL, *cur;
 	GSList *ptr;
@@ -414,7 +416,7 @@ double _gog_plot1_5d_get_percent_value (GogPlot *plot, unsigned series, unsigned
 			for (j = 0; j < cur->base.num_elements; j++)
 				model->sums[j] += vals[j];
 		}
-		
+
 	} else
 		for (ptr = plot->series ; ptr != NULL ; ptr = ptr->next)
 			if (0 == series--)
@@ -726,9 +728,12 @@ go_plugin_init (GOPlugin *plugin, GOCmdContext *cc)
 	gog_minmax_series_register_type (module);
 	gog_minmax_plot_register_type (module);
 	gog_minmax_view_register_type (module);
+
+	register_embedded_stuff ();
 }
 
 G_MODULE_EXPORT void
 go_plugin_shutdown (GOPlugin *plugin, GOCmdContext *cc)
 {
+	unregister_embedded_stuff ();
 }
