@@ -310,12 +310,9 @@ gog_histogram_plot_populate_editor (GogObject *item,
 {
 	GtkWidget  *w;
 	GogHistogramPlot *hist = GOG_HISTOGRAM_PLOT (item);
-	char const *dir = go_plugin_get_dir_name (
-		go_plugins_get_plugin_by_id ("GOffice_plot_distrib"));
-	char	 *path = g_build_filename (dir, "gog-histogram-prefs.ui", NULL);
-	GtkBuilder *gui = go_gtk_builder_new (path, GETTEXT_PACKAGE, cc);
-
-	g_free (path);
+	GtkBuilder *gui =
+		go_gtk_builder_new ("res:go:plot_distrib/gog-histogram-prefs.ui",
+				    GETTEXT_PACKAGE, cc);
         if (gui != NULL) {
 		w = go_gtk_builder_get_widget (gui, "vertical");
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), hist->vertical);
@@ -431,13 +428,9 @@ gog_double_histogram_plot_populate_editor (GogObject	*gobj,
 	GtkTable *table;
 	GtkWidget *w;
 	GogDataset *set = GOG_DATASET (gobj);
-	char const *dir = go_plugin_get_dir_name (
-		go_plugins_get_plugin_by_id ("GOffice_plot_distrib"));
-	char	 *path = g_build_filename (dir, "gog-double-histogram-prefs.ui", NULL);
-	GtkBuilder *gui = go_gtk_builder_new (path, GETTEXT_PACKAGE, cc);
-
-	g_free (path);
-
+	GtkBuilder *gui =
+		go_gtk_builder_new ("res:go:plot_distrib/gog-double-histogram-prefs.ui",
+				    GETTEXT_PACKAGE, cc);
 	if (gui != NULL) {
 		table = GTK_TABLE (gtk_builder_get_object (gui, "double-histogram-prefs"));
 		w = GTK_WIDGET (gog_data_allocator_editor (dalloc, set, 0, GOG_DATA_SCALAR));
@@ -760,35 +753,42 @@ gog_histogram_plot_view_render (GogView *view, GogViewAllocation const *bbox)
 					alloc.x = area->x + 2; /* FIXME: replace 2 by something configurable */
 					alloc.y = area->y + 2;
 					gog_renderer_draw_text (view->renderer, text, &alloc,
-							        GO_ANCHOR_NORTH_WEST, FALSE);
+							        GO_ANCHOR_NORTH_WEST, FALSE,
+					                        GTK_JUSTIFY_LEFT, -1.);
 					text = (text2)? text2: _("Second values");
 					alloc.y = area->y + area->h - 2;
 					gog_renderer_draw_text (view->renderer, text, &alloc,
-							        GO_ANCHOR_SOUTH_WEST, FALSE);
+							        GO_ANCHOR_SOUTH_WEST, FALSE,
+					                        GTK_JUSTIFY_LEFT, -1.);
 				} else {
 					alloc.x = area->x + area->w - 2; /* FIXME: replace 2 by something configurable */
 					alloc.y = area->y + area->h - 2;
 					gog_renderer_draw_text (view->renderer, text, &alloc,
-							        GO_ANCHOR_SOUTH_EAST, FALSE);
+							        GO_ANCHOR_SOUTH_EAST, FALSE,
+					                        GTK_JUSTIFY_LEFT, -1.);
 					text = (text2)? text2: _("Second values");
 					alloc.x = area->x + 2;
 					gog_renderer_draw_text (view->renderer, text, &alloc,
-							        GO_ANCHOR_SOUTH_WEST, FALSE);
+							        GO_ANCHOR_SOUTH_WEST, FALSE,
+					                        GTK_JUSTIFY_LEFT, -1.);
 				}
 			} else {
 				alloc.x = area->x + area->w - 2; /* FIXME: replace 2 by something configurable */
 				alloc.y = area->y + 2;
 				gog_renderer_draw_text (view->renderer, text, &alloc,
-					                GO_ANCHOR_NORTH_EAST, FALSE);
+					                GO_ANCHOR_NORTH_EAST, FALSE,
+				                        GTK_JUSTIFY_LEFT, -1.);
 				text = (text2)? text2: _("Second values");
 				if (model->vertical) {
 					alloc.y = area->y + area->h - 2;
 					gog_renderer_draw_text (view->renderer, text, &alloc,
-							        GO_ANCHOR_SOUTH_EAST, FALSE);
+							        GO_ANCHOR_SOUTH_EAST, FALSE,
+					                        GTK_JUSTIFY_LEFT, -1.);
 				} else {
 					alloc.x = area->x + 2;
 					gog_renderer_draw_text (view->renderer, text, &alloc,
-							        GO_ANCHOR_NORTH_WEST, FALSE);
+							        GO_ANCHOR_NORTH_WEST, FALSE,
+					                        GTK_JUSTIFY_LEFT, -1.);
 				}
 			}
 			g_free (text1);
