@@ -49,6 +49,8 @@
 #include <goffice/gtk/goffice-gtk.h>
 #endif
 
+#include "embedded-stuff.c"
+
 typedef struct {
 	GogPlotClass	base;
 } GogRTPlotClass;
@@ -390,15 +392,10 @@ gog_polar_area_populate_editor (GogObject *obj,
                              GOCmdContext *cc)
 {
 #ifdef GOFFICE_WITH_GTK
-	GtkBuilder *gui;
-	char const *dir;
-	char *path;
 	GogObjectClass *gog_class = (GogObjectClass *) g_type_class_peek_parent (G_OBJECT_GET_CLASS (obj));
-
-	dir = go_plugin_get_dir_name (go_plugins_get_plugin_by_id ("GOffice_plot_radar"));
-	path = g_build_filename (dir, "gog-polar-prefs.ui", NULL);
-	gui = go_gtk_builder_new (path, GETTEXT_PACKAGE, cc);
-	g_free (path);
+	GtkBuilder *gui =
+		go_gtk_builder_new ("res:go:plot_radar/gog-polar-prefs.ui",
+				    GETTEXT_PACKAGE, cc);
 
 	if (gui != NULL) {
 		GtkWidget *w = go_gtk_builder_get_widget (gui, "before-grid");
@@ -584,15 +581,9 @@ gog_color_polar_plot_populate_editor (GogObject *obj,
 				   GOCmdContext *cc)
 {
 #ifdef GOFFICE_WITH_GTK
-	GtkBuilder *gui;
-	char const *dir;
-	char *path;
-
-	dir = go_plugin_get_dir_name (go_plugins_get_plugin_by_id ("GOffice_plot_radar"));
-	path = g_build_filename (dir, "gog-color-polar-prefs.ui", NULL);
-	gui = go_gtk_builder_new (path, GETTEXT_PACKAGE, cc);
-	g_free (path);
-
+	GtkBuilder *gui =
+		go_gtk_builder_new ("res:go:plot_radar/gog-color-polar-prefs.ui",
+				    GETTEXT_PACKAGE, cc);
 	if (gui != NULL) {
 		GtkWidget *w = go_gtk_builder_get_widget (gui, "hide-outliers");
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
@@ -1541,9 +1532,12 @@ go_plugin_init (GOPlugin *plugin, GOCmdContext *cc)
 	gog_rt_series_element_register_type (module);
 	gog_polar_series_register_type (module);
 	gog_color_polar_series_register_type (module);
+
+	register_embedded_stuff ();
 }
 
 G_MODULE_EXPORT void
 go_plugin_shutdown (GOPlugin *plugin, GOCmdContext *cc)
 {
+	unregister_embedded_stuff ();
 }
